@@ -18,10 +18,8 @@
 # We used to import pygtk which sets things to utf-8 and masks ascii encoding errors.
 # It's usually what we want, and there are not many downsides, so replicate it here.
 import sys
-if sys.version_info[0] == 2:
-    import __builtin__
-    __builtin__.reload(sys)
-    sys.setdefaultencoding("utf-8")
+
+assert sys.version_info[0] == 3, "JHBuild requires Python 3"
 
 from jhbuild import monkeypatch
 del monkeypatch
