@@ -21,7 +21,8 @@ from optparse import make_option
 
 import jhbuild.moduleset
 from jhbuild.commands import Command, register_command
-from jhbuild.errors import UsageError, FatalError, CommandError
+from jhbuild.errors import FatalError
+from jhbuild.utils import uprint, N_, _
 
 
 class cmd_rdepends(Command):
@@ -53,9 +54,9 @@ class cmd_rdepends(Command):
 
         # get all modules but those that are a dependency of modname
         dependencies_list = [x.name for x in module_set.get_module_list([modname])]
-        dependencies_list.remove(modname)
-        modules = module_set.get_full_module_list(skip = dependencies_list,
-                ignore_cycles = True)
+        if modname in dependencies_list:
+            dependencies_list.remove(modname)
+        modules = module_set.get_full_module_list(skip=dependencies_list)
         modules = modules[[x.name for x in modules].index(modname)+1:]
 
         # iterate over remaining modules, and print those with modname as dep;
@@ -67,9 +68,7 @@ class cmd_rdepends(Command):
                 if modname in module.dependencies:
                     uprint(module.name)
             else:
-                module_list = module_set.get_module_list([module.name],
-                                                         ignore_cycles=True,
-                                                         ignore_missing=True)
+                module_list = module_set.get_module_list([module.name])
                 if modname in [x.name for x in module_list]:
                     seen_modules.append(module.name)
                     deps = ''
