@@ -17,9 +17,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from __future__ import print_function
+
 from optparse import make_option
 import logging
-import os.path
 import sys
 
 import jhbuild.moduleset
@@ -29,7 +30,9 @@ from jhbuild.commands.base import cmd_build
 from jhbuild.utils.systeminstall import SystemInstall
 from jhbuild.modtypes.systemmodule import SystemModule
 from jhbuild.versioncontrol.tarball import TarballBranch
+from jhbuild.utils import N_, _
 from jhbuild.utils import cmds
+from jhbuild.utils.compat import iteritems
 
 class cmd_sysdeps(cmd_build):
     doc = N_('Check and install tarball dependencies using system packages')
@@ -51,7 +54,7 @@ class cmd_sysdeps(cmd_build):
                         action="store_true", default = False,
                         dest="assume_yes",
                         help=_('assume yes/the default answer to interactive questions during installation of system '
-                                + 'dependencies"'))])
+                               + 'dependencies"'))])
 
     def run(self, config, options, args, help=None):
 
@@ -79,9 +82,9 @@ class cmd_sysdeps(cmd_build):
         if options.dump_all:
             for module in module_list:
                 if (isinstance(module, SystemModule) or isinstance(module.branch, TarballBranch) and
-                                                        module.pkg_config is not None):
+                        module.pkg_config is not None):
                     if module.pkg_config is not None:
-                        print 'pkgconfig:{0}'.format(module.pkg_config[:-3]) # remove .pc
+                        print('pkgconfig:{0}'.format(module.pkg_config[:-3])) # remove .pc
 
                     if module.systemdependencies is not None:
                         for dep_type, value, altdeps in module.systemdependencies:
@@ -98,7 +101,7 @@ class cmd_sysdeps(cmd_build):
         have_too_old = False
 
         if options.dump:
-            for module, (req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+            for module, (req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
                 if new_enough:
                     continue
 
@@ -117,7 +120,7 @@ class cmd_sysdeps(cmd_build):
                     assert (module.pkg_config or module.systemdependencies)
 
                     if module.pkg_config is not None:
-                        print 'pkgconfig:{0}'.format(module.pkg_config[:-3]) # remove .pc
+                        print('pkgconfig:{0}'.format(module.pkg_config[:-3])) # remove .pc
 
                     if module.systemdependencies is not None:
                         for dep_type, value, altdeps in module.systemdependencies:
@@ -131,8 +134,8 @@ class cmd_sysdeps(cmd_build):
 
             return
 
-        print _('System installed packages which are new enough:')
-        for module,(req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+        print(_('System installed packages which are new enough:'))
+        for module,(req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
             if (installed_version is not None) and new_enough and (config.partial_build or systemmodule):
                 have_new_enough = True
                 print ('    %s %s' % (module.name,
@@ -140,63 +143,63 @@ class cmd_sysdeps(cmd_build):
                                                   req_version,
                                                   installed_version)))
         if not have_new_enough:
-            print _('  (none)')
+            print(_('  (none)'))
 
-        print _('Required packages:')
-        print _('  System installed packages which are too old:')
-        for module, (req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+        print(_('Required packages:'))
+        print(_('  System installed packages which are too old:'))
+        for module, (req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
             if (installed_version is not None) and (not new_enough) and systemmodule:
                 have_too_old = True
-                print ('    %s %s' % (module.name,
-                                      fmt_details(module.pkg_config,
-                                                  req_version,
-                                                  installed_version)))
+                print('    %s %s' % (module.name,
+                                     fmt_details(module.pkg_config,
+                                                 req_version,
+                                                 installed_version)))
         if not have_too_old:
-            print _('    (none)')
+            print(_('    (none)'))
 
-        print _('  No matching system package installed:')
+        print(_('  No matching system package installed:'))
         uninstalled = []
-        for module, (req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+        for module, (req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
             if installed_version is None and (not new_enough) and systemmodule:
-                print ('    %s %s' % (module.name,
-                                      fmt_details(module.pkg_config,
-                                                  req_version,
-                                                  installed_version)))
+                print('    %s %s' % (module.name,
+                                     fmt_details(module.pkg_config,
+                                                 req_version,
+                                                 installed_version)))
                 if module.pkg_config is not None:
                     uninstalled.append((module.name, 'pkgconfig', module.pkg_config[:-3])) # remove .pc
                 elif module.systemdependencies is not None:
                     for dep_type, value, altdeps in module.systemdependencies:
                         uninstalled.append((module.name, dep_type, value))
         if len(uninstalled) == 0:
-            print _('    (none)')
+            print(_('    (none)'))
 
         have_too_old = False
 
         if config.partial_build:
-            print _('Optional packages: (JHBuild will build the missing packages)')
-            print _('  System installed packages which are too old:')
-            for module, (req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+            print(_('Optional packages: (JHBuild will build the missing packages)'))
+            print(_('  System installed packages which are too old:'))
+            for module, (req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
                 if (installed_version is not None) and (not new_enough) and (not systemmodule):
                     have_too_old = True
-                    print ('    %s %s' % (module.name,
-                                          fmt_details(module.pkg_config,
-                                                      req_version,
-                                                      installed_version)))
+                    print('    %s %s' % (module.name,
+                                         fmt_details(module.pkg_config,
+                                                     req_version,
+                                                     installed_version)))
             if not have_too_old:
-                print _('    (none)')
+                print(_('    (none)'))
 
-            print _('  No matching system package installed:')
-            for module,(req_version, installed_version, new_enough, systemmodule) in module_state.iteritems():
+            print(_('  No matching system package installed:'))
+            for module,(req_version, installed_version, new_enough, systemmodule) in iteritems(module_state):
                 if installed_version is None and (not new_enough) and (not systemmodule):
-                    print ('    %s %s' % (module.name,
-                                          fmt_details(module.pkg_config,
-                                                      req_version,
-                                                      installed_version)))
+                    print('    %s %s' % (module.name,
+                                         fmt_details(module.pkg_config,
+                                                     req_version,
+                                                     installed_version)))
                     if module.pkg_config is not None:
                         uninstalled.append((module.name, 'pkgconfig', module.pkg_config[:-3])) # remove .pc
 
             if len(uninstalled) == 0:
-                print _('    (none)')
+                print(_('    (none)'))
 
         if options.install:
             installer = SystemInstall.find_best()
@@ -215,7 +218,7 @@ class cmd_sysdeps(cmd_build):
                 logging.info(_("No uninstalled system dependencies to install for modules: %r") % (modules, ))
             else:
                 logging.info(_("Installing dependencies on system: %s") % \
-                               ' '.join(pkg[0] for pkg in uninstalled))
+                             ' '.join(pkg[0] for pkg in uninstalled))
                 installer.install(uninstalled, assume_yes=options.assume_yes)
 
 register_command(cmd_sysdeps)
