@@ -23,7 +23,7 @@ __all__ = [
     'register_module_type',
     'parse_xml_node',
     'Package',
-    'get_dependencies'
+    'get_dependencies',
     'get_branch'
     ]
 
@@ -31,11 +31,14 @@ import os
 import re
 import shutil
 import logging
+import importlib
 
 from jhbuild.errors import FatalError, CommandError, BuildStateError, \
              SkipToEnd, UndefinedRepositoryError
 from jhbuild.utils.sxml import sxml
+from jhbuild.utils import inpath, try_import_module, N_, _
 import jhbuild.utils.fileutils as fileutils
+from jhbuild.utils.compat import filterlist
 
 _module_types = {}
 def register_module_type(name, parse_func):
@@ -44,19 +47,16 @@ def register_module_type(name, parse_func):
 def register_lazy_module_type(name, module):
     def parse_func(node, config, uri, repositories, default_repo):
         old_func = _module_types[name]
-        mod = __import__(module)
+        importlib.import_module(module)
         assert _module_types[name] != old_func, (
             'module did not register new parser_func for %s' % name)
         return _module_types[name](node, config, uri, repositories, default_repo)
     _module_types[name] = parse_func
 
 def parse_xml_node(node, config, uri, repositories, default_repo):
-    if not _module_types.has_key(node.nodeName):
-        try:
-            __import__('jhbuild.modtypes.%s' % node.nodeName)
-        except ImportError:
-            pass
-    if not _module_types.has_key(node.nodeName):
+    if node.nodeName not in _module_types:
+        try_import_module('jhbuild.modtypes.%s' % node.nodeName)
+    if node.nodeName not in _module_types:
         raise FatalError(_('unknown module type %s') % node.nodeName)
 
     parser = _module_types[node.nodeName]
@@ -78,9 +78,9 @@ def get_dependencies(node):
                             node.getAttribute('id'))
                 list.append(package)
 
-    def add_to_system_dependencies(lst, childnode):
+    def add_to_system_dependencies(lst, childnode, tag='dep'):
         for dep in childnode.childNodes:
-            if dep.nodeType == dep.ELEMENT_NODE and dep.nodeName == 'dep':
+            if dep.nodeType == dep.ELEMENT_NODE and dep.nodeName == tag:
                 typ = dep.getAttribute('type')
                 if not typ:
                     raise FatalError(_('%(node)s node for %(module)s module is'
@@ -95,10 +95,14 @@ def get_dependencies(node):
                                      {'node_name'   : 'dep',
                                       'module_name' : node.getAttribute('id'),
                                       'attribute'   : 'name'})
-                lst.append((typ, name))
+                altdeps = []
+                if dep.childNodes:
+                    add_to_system_dependencies(altdeps, dep, 'altdep')
+                lst.append((typ, name, altdeps))
 
     for childnode in node.childNodes:
-        if childnode.nodeType != childnode.ELEMENT_NODE: continue
+        if childnode.nodeType != childnode.ELEMENT_NODE:
+            continue
         if childnode.nodeName == 'dependencies':
             add_to_list(dependencies, childnode)
         elif childnode.nodeName == 'suggests':
@@ -121,7 +125,7 @@ def get_node_content(node):
 def find_first_child_node(node, name):
     for childnode in node.childNodes:
         if (childnode.nodeType == childnode.ELEMENT_NODE and
-            childnode.nodeName == name):
+                childnode.nodeName == name):
             return childnode
     return None
 
@@ -170,7 +174,7 @@ class Package:
     PHASE_START = 'start'
     PHASE_DONE  = 'done'
     def __init__(self, name, branch=None, dependencies = [], after = [],
-                  suggests = [], systemdependencies = [], pkg_config=None):
+                 suggests = [], systemdependencies = [], pkg_config=None):
         self.name = name
         self.branch = branch
         self.dependencies = dependencies
@@ -193,9 +197,9 @@ class Package:
         args = args.replace('${libdir}', libdir)
         return args
 
-    def get_extra_env(self):
+    @property
+    def extra_env(self):
         return self.config.module_extra_env.get(self.name)
-    extra_env = property(get_extra_env)
 
     def get_srcdir(self, buildscript):
         raise NotImplementedError
@@ -220,11 +224,11 @@ class Package:
             if os.path.isdir(subpath):
                 self._clean_la_files_in_dir(buildscript, subpath)
             elif name.endswith('.la'):
-                    try:
-                        logging.info(_('Deleting .la file: %r') % (subpath, ))
-                        os.unlink(subpath)
-                    except OSError:
-                        pass
+                try:
+                    logging.info(_('Deleting .la file: %r') % (subpath, ))
+                    os.unlink(subpath)
+                except OSError:
+                    pass
 
     def _clean_la_files(self, buildscript, installroot):
         """This method removes all .la files. See bug 654013."""
@@ -234,6 +238,20 @@ class Package:
         if os.path.isdir(prefixdir):
             self._clean_la_files_in_dir(self, prefixdir)
 
+    def _clean_texinfo_dir_files(self, buildscript, installroot):
+        """This method removes GNU Texinfo dir files."""
+        assert os.path.isabs(installroot)
+        assert os.path.isabs(buildscript.config.prefix)
+        prefixdir = os.path.join(installroot, buildscript.config.prefix[1:])
+        if os.path.isdir(prefixdir):
+            dirfile = os.path.join(prefixdir, 'share/info/dir')
+            if os.path.isfile(dirfile):
+                try:
+                    logging.info(_('Deleting dir file: %r') % (dirfile, ))
+                    os.unlink(dirfile)
+                except OSError:
+                    pass
+
     def _process_install_files(self, installroot, curdir, prefix, errors):
         """Strip the prefix from all files in the install root, and move
 them into the prefix."""
@@ -277,9 +295,9 @@ them into the prefix."""
                     try:
                         fileutils.rename(src_path, dest_path)
                         num_copied += 1
-                    except OSError, e:
+                    except OSError as e:
                         errors.append("%s: '%s'" % (str(e), dest_path))
-            except OSError, e:
+            except OSError as e:
                 errors.append(str(e))
         return num_copied
 
@@ -287,6 +305,7 @@ them into the prefix."""
         assert self.supports_install_destdir
         destdir = self.get_destdir(buildscript)
         self._clean_la_files(buildscript, destdir)
+        self._clean_texinfo_dir_files(buildscript, destdir)
 
         prefix_without_drive = os.path.splitdrive(buildscript.config.prefix)[1]
         stripped_prefix = prefix_without_drive[1:]
@@ -298,7 +317,6 @@ them into the prefix."""
         new_contents = fileutils.accumulate_dirtree_contents(destdir_prefix)
         errors = []
         if os.path.isdir(destdir_prefix):
-            destdir_install = True
             logging.info(_('Moving temporary DESTDIR %r into build prefix') % (destdir, ))
             num_copied = self._process_install_files(destdir, destdir_prefix,
                                                      buildscript.config.prefix,
@@ -308,7 +326,7 @@ them into the prefix."""
             # $JHBUILD_PREFIX/_jhbuild/root-foo/$JHBUILD_PREFIX
             # Remove them one by one to clean the tree to the state we expect,
             # so we can better spot leftovers or broken things.
-            prefix_dirs = filter(lambda x: x != '', stripped_prefix.split(os.sep))
+            prefix_dirs = filterlist(lambda x: x != '', stripped_prefix.split(os.sep))
             while len(prefix_dirs) > 0:
                 dirname = prefix_dirs.pop()
                 subprefix = os.path.join(*([destdir] + prefix_dirs))
@@ -316,7 +334,7 @@ them into the prefix."""
                 assert target.startswith(buildscript.config.prefix)
                 try:
                     os.rmdir(target)
-                except OSError, e:
+                except OSError:
                     pass
 
             remaining_files = os.listdir(destdir)
@@ -344,7 +362,7 @@ them into the prefix."""
             to_delete = set()
             previous_entry = buildscript.moduleset.packagedb.get(self.name)
             if previous_entry:
-                previous_contents = previous_entry.get_manifest()
+                previous_contents = previous_entry.manifest
                 if previous_contents:
                     to_delete.update(fileutils.filter_files_by_prefix(self.config, previous_contents))
 
@@ -400,7 +418,7 @@ them into the prefix."""
         method = getattr(self, 'do_' + phase)
         try:
             method(buildscript)
-        except (CommandError, BuildStateError), e:
+        except (CommandError, BuildStateError) as e:
             error_phases = []
             if hasattr(method, 'error_phases'):
                 error_phases = method.error_phases
@@ -412,7 +430,7 @@ them into the prefix."""
         return hasattr(self, 'do_' + phase)
 
     def check_build_policy(self, buildscript):
-        if not buildscript.config.build_policy in ('updated', 'updated-deps'):
+        if buildscript.config.build_policy not in ('updated', 'updated-deps'):
             return
 
         # Always trigger a build for dirty branches if supported by the version
@@ -433,7 +451,7 @@ them into the prefix."""
             install_date = buildscript.moduleset.packagedb.installdate(self.name)
             for dep in self.dependencies:
                 install_date_dep = buildscript.moduleset.packagedb.installdate(dep)
-                if install_date_dep > install_date:
+                if install_date_dep is not None and install_date is not None and install_date_dep > install_date:
                     # a dependency has been updated
                     return None
             else:
@@ -477,6 +495,8 @@ them into the prefix."""
 
     def branch_to_sxml(self):
         """Serialize this module's checkout branch as sxml."""
+        if self.branch is None:
+            return [sxml.branch]
         return self.branch.to_sxml()
 
     @classmethod
@@ -495,11 +515,58 @@ them into the prefix."""
         instance.dependencies += instance.branch.repository.get_sysdeps()
         return instance
 
+class NinjaModule(Package):
+    '''A base class for modules that use the command 'ninja' within the build
+    process.'''
+    def __init__(self, name, branch=None,
+                 ninjaargs='',
+                 ninjainstallargs='',
+                 ninjafile='build.ninja'):
+        Package.__init__(self, name, branch=branch)
+        self.ninjacmd = None
+        self.ninjaargs = ninjaargs
+        self.ninjainstallargs = ninjainstallargs
+        self.ninjafile = ninjafile
+
+    def get_ninjaargs(self, buildscript):
+        ninjaargs = ' %s %s' % (self.ninjaargs,
+                                self.config.module_ninjaargs.get(
+                                    self.name, self.config.ninjaargs))
+        if not self.supports_parallel_build:
+            ninjaargs = re.sub(r'-j\w*\d+', '', ninjaargs) + ' -j 1'
+        return self.eval_args(ninjaargs).strip()
+
+    def get_ninjacmd(self, config):
+        if self.ninjacmd:
+            return self.ninjacmd
+        for cmd in ['ninja', 'ninja-build']:
+            if inpath(cmd, os.environ['PATH'].split(os.pathsep)):
+                self.ninjacmd = cmd
+                break
+        return self.ninjacmd
+
+    def ninja(self, buildscript, target='', ninjaargs=None, env=None):
+        ninjacmd = os.environ.get('NINJA', self.get_ninjacmd(buildscript.config))
+        if ninjacmd is None:
+            raise BuildStateError(_('ninja not found; use NINJA to point to a specific ninja binary'))
+
+        if ninjaargs is None:
+            ninjaargs = self.get_ninjaargs(buildscript)
+
+        extra_env = (self.extra_env or {}).copy()
+        for k in (env or {}):
+            extra_env[k] = env[k]
+
+        cmd = '{ninja} {ninjaargs} {target}'.format(ninja=ninjacmd,
+                                                    ninjaargs=ninjaargs,
+                                                    target=target)
+        buildscript.execute(cmd, cwd=self.get_builddir(buildscript), extra_env=extra_env)
+
 class MakeModule(Package):
     '''A base class for modules that use the command 'make' within the build
     process.'''
     def __init__(self, name, branch=None, makeargs='', makeinstallargs='',
-                  makefile='Makefile', needs_gmake=False):
+                 makefile='Makefile', needs_gmake=False):
         Package.__init__(self, name, branch=branch)
         self.makeargs = makeargs
         self.makeinstallargs = makeinstallargs
@@ -529,12 +596,12 @@ class MakeModule(Package):
         makecmd = os.environ.get('MAKE', self.get_makecmd(buildscript.config))
 
         if makeargs is None:
-            makeargs = self.get_makeargs(self, buildscript)
+            makeargs = self.get_makeargs(buildscript)
 
         cmd = '{pre}{make} {makeargs} {target}'.format(pre=pre,
-                                                        make=makecmd,
-                                                        makeargs=makeargs,
-                                                        target=target)
+                                                       make=makecmd,
+                                                       makeargs=makeargs,
+                                                       target=target)
         buildscript.execute(cmd, cwd = self.get_builddir(buildscript), extra_env = self.extra_env)
 
 class DownloadableModule:
@@ -565,6 +632,14 @@ class DownloadableModule:
         return False
 
     def do_force_checkout(self, buildscript):
+        # Try to wipe the build directory. Ignore exceptions if the child class
+        # does not implement get_builddir().
+        try:
+            builddir = self.get_builddir(buildscript)
+            if os.path.exists(builddir):
+                shutil.rmtree(builddir)
+        except Exception:
+            pass
         buildscript.set_action(_('Checking out'), self)
         self.branch.force_checkout(buildscript)
     do_force_checkout.error_phases = [PHASE_FORCE_CHECKOUT]
