@@ -22,15 +22,13 @@ __metaclass__ = type
 
 import os
 import stat
-try:
-    import hashlib
-except ImportError:
-    import md5 as hashlib
+import hashlib
 
-from jhbuild.errors import FatalError, BuildStateError, CommandError
+from jhbuild.errors import FatalError, CommandError
 from jhbuild.modtypes import \
      DownloadableModule, register_module_type, MakeModule
 from jhbuild.versioncontrol.tarball import TarballBranch
+from jhbuild.utils import _
 
 __all__ = [ 'AutogenModule' ]
 
@@ -62,11 +60,13 @@ class AutogenModule(MakeModule, DownloadableModule):
                  autogen_template=None,
                  check_target=True,
                  supports_static_analyzer=True,
-                 needs_gmake=True):
+                 needs_gmake=True,
+                 supports_unknown_configure_options=True):
         MakeModule.__init__(self, name, branch=branch, makeargs=makeargs,
                             makeinstallargs=makeinstallargs, makefile=makefile, needs_gmake=needs_gmake)
         self.autogenargs = autogenargs
         self.supports_non_srcdir_builds = supports_non_srcdir_builds
+        self.force_non_srcdir_builds = False
         self.skip_autogen = skip_autogen
         self.skip_install_phase = skip_install_phase
         self.uninstall_before_install = uninstall_before_install
@@ -75,23 +75,26 @@ class AutogenModule(MakeModule, DownloadableModule):
         self.check_target = check_target
         self.supports_install_destdir = True
         self.supports_static_analyzer = supports_static_analyzer
+        self.supports_unknown_configure_options = supports_unknown_configure_options
 
     def get_srcdir(self, buildscript):
         return self.branch.srcdir
 
     def get_builddir(self, buildscript):
+        builddir = self.get_srcdir(buildscript)
         if buildscript.config.buildroot and self.supports_non_srcdir_builds:
             d = buildscript.config.builddir_pattern % (
                 self.branch.checkoutdir or self.branch.get_module_basename())
-            return os.path.join(buildscript.config.buildroot, d)
-        else:
-            return self.get_srcdir(buildscript)
+            builddir = os.path.join(buildscript.config.buildroot, d)
+        if self.force_non_srcdir_builds and builddir == self.get_srcdir(buildscript):
+            builddir = os.path.join(builddir, 'build')
+        return builddir
 
     def _file_exists_and_is_newer_than(self, potential, other):
         try:
             other_stbuf = os.stat(other)
             potential_stbuf = os.stat(potential)
-        except OSError, e:
+        except OSError:
             return False
         return potential_stbuf.st_mtime > other_stbuf.st_mtime
 
@@ -112,17 +115,20 @@ class AutogenModule(MakeModule, DownloadableModule):
         else:
             template = ("%(srcdir)s/%(autogen-sh)s --prefix %(prefix)s %(autogenargs)s ")
 
+        default_autogenargs = (self.config.autogenargs
+            if self.supports_unknown_configure_options else '')
         autogenargs = self.autogenargs + ' ' + self.config.module_autogenargs.get(
-                self.name, self.config.autogenargs)
+                self.name, default_autogenargs)
 
-        if self.config.disable_Werror:
-            autogenargs = autogenargs + ' ' + '--disable-Werror'
+        if self.config.disable_Werror and self.supports_unknown_configure_options:
+            autogenargs = '--disable-Werror' + ' ' + autogenargs
 
         vars = {'prefix': os.path.splitdrive(buildscript.config.prefix)[1],
                 'autogen-sh': self.autogen_sh,
                 'autogenargs': autogenargs}
 
-        if buildscript.config.buildroot and self.supports_non_srcdir_builds:
+        if buildscript.config.buildroot and self.supports_non_srcdir_builds or \
+           self.force_non_srcdir_builds:
             vars['srcdir'] = self.get_srcdir(buildscript)
         else:
             vars['srcdir'] = '.'
@@ -143,7 +149,7 @@ class AutogenModule(MakeModule, DownloadableModule):
         # can safely assume it will be the same as {prefix} and substitute it
         # right now, so the printed command can be copy/pasted afterwards.
         # (GNOME #580272)
-        if not '--exec-prefix' in template:
+        if '--exec-prefix' not in template:
             cmd = cmd.replace('${exec_prefix}', vars['prefix'])
 
         self.configure_cmd = cmd
@@ -179,7 +185,7 @@ class AutogenModule(MakeModule, DownloadableModule):
             configure_hash = db_entry.metadata.get('configure-hash')
             if configure_hash:
                 configure_cmd = self._get_configure_cmd(buildscript)
-                if hashlib.md5(configure_cmd).hexdigest() != configure_hash:
+                if hashlib.md5(configure_cmd.encode("utf-8")).hexdigest() != configure_hash:
                     return False
             else:
                 # force one-time reconfigure if no configure-hash
@@ -210,7 +216,7 @@ class AutogenModule(MakeModule, DownloadableModule):
 
     def do_configure(self, buildscript):
         builddir = self.get_builddir(buildscript)
-        if buildscript.config.buildroot and not os.path.exists(builddir):
+        if not os.path.exists(builddir):
             os.makedirs(builddir)
         buildscript.set_action(_('Configuring'), self)
 
@@ -218,11 +224,15 @@ class AutogenModule(MakeModule, DownloadableModule):
 
         srcdir = self.get_srcdir(buildscript)
         try:
-            if not (os.stat(os.path.join(srcdir, self.autogen_sh))[stat.ST_MODE] & 0111):
-                os.chmod(os.path.join(srcdir, self.autogen_sh), 0755)
-        except:
+            if not (os.stat(os.path.join(srcdir, self.autogen_sh))[stat.ST_MODE] & 0o111):
+                os.chmod(os.path.join(srcdir, self.autogen_sh), 0o755)
+        except EnvironmentError:
             pass
 
+        if self.autogen_sh == 'autoreconf':
+            buildscript.execute(['autoreconf', '-fi'], cwd=srcdir)
+            os.chmod(os.path.join(srcdir, 'configure'), 0o755)
+
         buildscript.execute(cmd, cwd = builddir, extra_env = self.extra_env)
     do_configure.depends = [PHASE_CHECKOUT]
     do_configure.error_phases = [PHASE_FORCE_CHECKOUT,
@@ -299,7 +309,7 @@ class AutogenModule(MakeModule, DownloadableModule):
 
     def do_install(self, buildscript):
         if self.uninstall_before_install:
-            packagedb =  buildscript.moduleset.packagedb
+            packagedb = buildscript.moduleset.packagedb
             if packagedb.check(self.name):
                 buildscript.set_action(_('Uninstalling old installed version'), self)
                 packagedb.uninstall(self.name)
@@ -310,6 +320,7 @@ class AutogenModule(MakeModule, DownloadableModule):
         self.process_install(buildscript, self.get_revision())
 
     do_install.depends = [PHASE_BUILD]
+    do_install.error_phases = [PHASE_CONFIGURE]
 
     def skip_install(self, buildscript, last_phase):
         return self.config.noinstall or self.skip_install_phase
@@ -340,6 +351,10 @@ class AutogenModule(MakeModule, DownloadableModule):
                  ('makeinstallargs', 'makeinstallargs', ''),
                  ('supports-non-srcdir-builds',
                   'supports_non_srcdir_builds', True),
+                 ('force-non-srcdir-builds',
+                  'force_non_srcdir_builds', False),
+                 ('supports-unknown-configure-options',
+                  'supports_unknown_configure_options', True),
                  ('skip-autogen', 'skip_autogen', False),
                  ('skip-install', 'skip_install_phase', False),
                  ('uninstall-before-install', 'uninstall_before_install', False),
@@ -365,7 +380,10 @@ def collect_args(instance, node, argtype):
 def parse_autotools(node, config, uri, repositories, default_repo):
     instance = AutogenModule.parse_from_xml(node, config, uri, repositories, default_repo)
 
-    instance.dependencies += ['automake', 'libtool', instance.get_makecmd(config)]
+    # Allow base packages such as autoconf/automake/libtool/etc. to skip the
+    # standard dependencies to prevent dependency cycles.
+    if node.getAttribute('bootstrap') != 'true':
+        instance.dependencies += ['automake', 'libtool', instance.get_makecmd(config)]
 
     instance.autogenargs = collect_args (instance, node, 'autogenargs')
     instance.makeargs = collect_args (instance, node, 'makeargs')
@@ -374,6 +392,12 @@ def parse_autotools(node, config, uri, repositories, default_repo):
     if node.hasAttribute('supports-non-srcdir-builds'):
         instance.supports_non_srcdir_builds = \
                 (node.getAttribute('supports-non-srcdir-builds') != 'no')
+    if node.hasAttribute('force-non-srcdir-builds'):
+        instance.force_non_srcdir_builds = \
+                (node.getAttribute('force-non-srcdir-builds') != 'no')
+    if node.hasAttribute('supports-unknown-configure-options'):
+        instance.supports_unknown_configure_options = \
+                (node.getAttribute('supports-unknown-configure-options') != 'no')
     if node.hasAttribute('skip-autogen'):
         skip_autogen = node.getAttribute('skip-autogen')
         if skip_autogen == 'true':
@@ -391,8 +415,8 @@ def parse_autotools(node, config, uri, repositories, default_repo):
 
     if node.hasAttribute('check-target'):
         instance.check_target = (node.getAttribute('check-target') == 'true')
-    if node.hasAttribute('static-analyzer'):
-        instance.supports_static_analyzer = (node.getAttribute('static-analyzer') == 'true')
+    if node.hasAttribute('supports-static-analyzer'):
+        instance.supports_static_analyzer = (node.getAttribute('supports-static-analyzer') == 'true')
 
     from jhbuild.versioncontrol.tarball import TarballBranch
     if node.hasAttribute('autogen-sh'):
