@@ -19,14 +19,9 @@
 
 __metaclass__ = type
 
-import sys
 import logging
 
-try:
-    import hashlib
-except ImportError:
-    hashlib = None
-
+from jhbuild.utils import _
 from jhbuild.modtypes import register_module_type, get_dependencies, find_first_child_node_content
 
 def parse_tarball(node, config, uri, repositories, default_repo):
@@ -57,7 +52,8 @@ def parse_tarball(node, config, uri, repositories, default_repo):
         makefile = node.getAttribute('makefile')
 
     for childnode in node.childNodes:
-        if childnode.nodeType != childnode.ELEMENT_NODE: continue
+        if childnode.nodeType != childnode.ELEMENT_NODE:
+            continue
         if childnode.nodeName == 'source':
             source_url = childnode.getAttribute('href')
             if childnode.hasAttribute('size'):
@@ -69,12 +65,14 @@ def parse_tarball(node, config, uri, repositories, default_repo):
                                 'module': name, 'size': childnode.getAttribute('size')})
             if childnode.hasAttribute('md5sum'):
                 source_hash = 'md5:' + childnode.getAttribute('md5sum')
-            if childnode.hasAttribute('hash') and hashlib:
+            if childnode.hasAttribute('hash'):
                 source_hash = childnode.getAttribute('hash')
         elif childnode.nodeName == 'patches':
             for patch in childnode.childNodes:
-                if patch.nodeType != patch.ELEMENT_NODE: continue
-                if patch.nodeName != 'patch': continue
+                if patch.nodeType != patch.ELEMENT_NODE:
+                    continue
+                if patch.nodeName != 'patch':
+                    continue
                 patchfile = patch.getAttribute('file')
                 if patch.hasAttribute('strip'):
                     patchstrip = int(patch.getAttribute('strip'))
@@ -85,9 +83,9 @@ def parse_tarball(node, config, uri, repositories, default_repo):
     # for tarballs, don't ever pass --enable-maintainer-mode
     autogenargs = autogenargs.replace('--enable-maintainer-mode', '')
 
-    dependencies, after, suggests = get_dependencies(node)
+    dependencies, after, suggests, systemdependencies = get_dependencies(node)
 
-    from autotools import AutogenModule
+    from .autotools import AutogenModule
     from jhbuild.versioncontrol.tarball import TarballBranch, TarballRepository
 
     # create a fake TarballRepository, and give it the moduleset uri
@@ -106,6 +104,7 @@ def parse_tarball(node, config, uri, repositories, default_repo):
     instance.dependencies = dependencies
     instance.after = after
     instance.suggests = suggests
+    instance.systemdependencies = systemdependencies
     instance.pkg_config = find_first_child_node_content(node, 'pkg-config')
     instance.config = config
 
