@@ -22,12 +22,11 @@
 __metaclass__ = type
 
 import os
-import re
 
-from jhbuild.errors import FatalError, BuildStateError, CommandError
+from jhbuild.errors import CommandError
 from jhbuild.modtypes import \
      Package, DownloadableModule, register_module_type
-from jhbuild.commands.sanitycheck import inpath
+from jhbuild.utils import _
 
 __all__ = [ 'WafModule' ]
 
@@ -77,8 +76,6 @@ class WafModule(Package, DownloadableModule):
         if buildscript.config.buildroot and not os.path.exists(builddir):
             os.makedirs(builddir)
         cmd = [self.waf_cmd, 'configure', '--prefix', buildscript.config.prefix]
-        if buildscript.config.use_lib64:
-            cmd += ["--libdir", os.path.join(buildscript.config.prefix, "lib64")]
         buildscript.execute(cmd, cwd=builddir, extra_env={'PYTHON': self.python_cmd})
     do_configure.depends = [PHASE_CHECKOUT]
     do_configure.error_phases = [PHASE_FORCE_CHECKOUT]
@@ -128,7 +125,7 @@ class WafModule(Package, DownloadableModule):
         else:
             cmd = [self.waf_cmd, 'dist']
         buildscript.execute(cmd, cwd=self.get_builddir(buildscript),
-                                extra_env={'PYTHON': self.python_cmd})
+                            extra_env={'PYTHON': self.python_cmd})
     do_dist.depends = [PHASE_BUILD]
     do_dist.error_phases = [PHASE_FORCE_CHECKOUT, PHASE_CONFIGURE]
 
